//
//
// Copyright (c) 2017 GetSocial BV. All rights reserved.
//

#import <Foundation/Foundation.h>
#import "GetSocialConstants.h"

#pragma mark - GetSocial Notification Key
typedef NSString *GetSocialNotificationKey NS_EXTENSIBLE_STRING_ENUM;

#pragma mark - GetSocial OpenActivity Notification Keys

/*!
 * GetSocialNotificationKey_OpenActivity_ActivityId and GetSocialNotificationKey_OpenActivity_FeedName are mutually exclusive.
 */
extern GetSocialNotificationKey GetSocialNotificationKey_OpenActivity_ActivityId;

/*!
 * Optional. Can be present with GetSocialNotificationKey_OpenActivity_ActivityId only.
 */
extern GetSocialNotificationKey GetSocialNotificationKey_OpenActivity_CommentId;

/*!
 * GetSocialNotificationKey_OpenActivity_ActivityId and GetSocialNotificationKey_OpenActivity_FeedName are mutually exclusive.
 */
extern GetSocialNotificationKey GetSocialNotificationKey_OpenActivity_FeedName;

#pragma mark - GetSocial OpenProfile Notification Keys

/*!
 * ID of user to be opened.
 */
extern GetSocialNotificationKey GetSocialNotificationKey_OpenProfile_UserId;

#pragma mark - GetSocial OpenUrl Notification Keys

/*!
 * URL to be opened.
 */
extern GetSocialNotificationKey GetSocialNotificationKey_OpenUrl_Url;

@interface GetSocialNotification : NSObject

/*!
 * Returns an enum value of the action.
 */
@property(nonatomic, readonly) GetSocialNotificationActionType action;

/*!
 * Returns an enum value of the type.
 */
@property(nonatomic, readonly) GetSocialNotificationType type;

/*!
 * Return was notification read by user or not.
 * @return YES, if notification was clicked by user or marked as read by developer.
 */
@property(nonatomic, readonly) BOOL wasRead;

/*!
 * Date of notification creation.
 * @return UNIX-timestamp of creation date in seconds.
 */
@property(nonatomic, readonly) NSUInteger createdAt;

/*!
 * Get the unique notification identifier.
 */
@property(nonatomic, copy, readonly) GetSocialId notificationId;

/*!
 * Data passed with action.
 */
@property(nonatomic, strong, readonly) NSDictionary<GetSocialNotificationKey, NSString *> *actionData;

/*!
 * Message of Push Notification.
 */
@property(nonatomic, copy, readonly) NSString *text;

/*!
 * Title of Push Notification.
 */
@property(nonatomic, copy, readonly) NSString *title;

/*!
 * @abstract Creates a new GetSocialNotification instance using the provided parameters.
 *
 * @param   notificationId  id of notification.
 * @param   type            type of notification.
 * @param   actionType      actionType.
 * @param   createdAt       date of notification creation.
 * @param   actionData      actionData.
 * @param   wasRead         notification was read or not.
 * @param   title           title of notification.
 * @param   text            text of notification.
 *
 * @return new instance.
 */
- (instancetype)initWithId:(GetSocialId)notificationId
                      type:(GetSocialNotificationType)type
                    action:(GetSocialNotificationActionType)actionType
                 createdAt:(NSUInteger)createdAt
                actionData:(NSDictionary<NSString *, NSString *> *)actionData
                   wasRead:(BOOL)wasRead
                     title:(NSString *)title
                      text:(NSString *)text;

@end
