//
//
// Copyright (c) 2018 GetSocial BV. All rights reserved.
//

#import <Foundation/Foundation.h>
#import <GetSocial/GetSocialConstants.h>

/*!
 * @typedef NS_ENUM(NSUInteger, GetSocialNotificationsFilter)
 * @abstract Defines query types.
 */
typedef NS_ENUM(NSUInteger, GetSocialNotificationsFilter) {
    /*!
     * @abstract No filter.
     */
    NotificationsNoFilter = 0,
    /*!
     * @abstract Notifications created before the specified activity.
     */
    NotificationsBefore,
    /*!
     * @abstract Notifications created after the specified activity.
     */
    NotificationsAfter
};

NS_ASSUME_NONNULL_BEGIN

/*!
 * @abstract Class to create notification queries.
 */
@interface GetSocialNotificationsQuery : NSObject

/*!
 * @abstract Query to get all notifications.
 */
+ (instancetype)readAndUnread;

/*!
 * @abstract Query to get all read notifications.
 */
+ (instancetype)read;

/*!
 * @abstract Query to get all unread notifications.
 */
+ (instancetype)unread;

/*!
 * @abstract Set notificaton types.
 *
 * @param types   notification types. Check @see GetSocialNotificationType enum for available notification types.
 */
- (void)setTypes:(NSArray *)types;

/*!
 * @abstract Sets all the available notification types.
 */
- (void)setAllTypes;

/*!
 * @abstract Sets filter.
 *
 * @param   filter          filter object
 * @param   notificationId  id of notification
 */
- (void)setFilter:(GetSocialNotificationsFilter)filter notificationId:(GetSocialId)notificationId;

/*!
 * @abstract Max. number of returned items.
 *
 * @param   limit   limit
 */
- (void)setLimit:(int)limit;

@end

NS_ASSUME_NONNULL_END
